==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebExporterEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseExporterDescriptionMetadata } from "./WebBaseExporterDescriptionMetadata";
import { WebExporterOptionsBaseDescriptionMetadata } from "./WebExporterOptionsBaseDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebExporterEventDetailDescription } from "./WebExporterEventDetailDescription";
/**
 * @hidden
 */
var WebExporterEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExporterEventDetailDescriptionMetadata, _super);
    function WebExporterEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterEventDetailDescriptionMetadata.b = function (a) {
        if (WebExporterEventDetailDescriptionMetadata.a == null) {
            WebExporterEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterEventDetailDescriptionMetadata.c(WebExporterEventDetailDescriptionMetadata.a);
        }
        if (a.j(WebExporterEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebExporterEventDetailDescriptionMetadata.a);
        WebBaseExporterDescriptionMetadata.d(a);
        WebExporterOptionsBaseDescriptionMetadata.d(a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebExporterEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterEventDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Exporter", "ExportedType:WebBaseExporter");
        a.item("Options", "ExportedType:WebExporterOptionsBase");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
        a.item("Cancel", "Boolean");
    };
    WebExporterEventDetailDescriptionMetadata.d = function (a) {
        WebExporterEventDetailDescriptionMetadata.b(a);
        a.aa("WebExporterEventDetail", function () { return new WebExporterEventDetailDescription(); });
        a.z("WebExporterEventDetail", WebExporterEventDetailDescriptionMetadata.a);
    };
    WebExporterEventDetailDescriptionMetadata.$t = markType(WebExporterEventDetailDescriptionMetadata, 'WebExporterEventDetailDescriptionMetadata');
    WebExporterEventDetailDescriptionMetadata.a = null;
    return WebExporterEventDetailDescriptionMetadata;
}(Base));
export { WebExporterEventDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebExporterEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseExporterDescriptionMetadata } from "./WebBaseExporterDescriptionMetadata";
import { WebExporterOptionsBaseDescriptionMetadata } from "./WebExporterOptionsBaseDescriptionMetadata";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebExporterEventDetailDescription } from "./WebExporterEventDetailDescription";
/**
 * @hidden
 */
var WebExporterEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExporterEventDetailDescriptionMetadata, _super);
    function WebExporterEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterEventDetailDescriptionMetadata.b = function (a) {
        if (WebExporterEventDetailDescriptionMetadata.a == null) {
            WebExporterEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterEventDetailDescriptionMetadata.c(WebExporterEventDetailDescriptionMetadata.a);
        }
        if (a.k(WebExporterEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebExporterEventDetailDescriptionMetadata.a);
        WebBaseExporterDescriptionMetadata.d(a);
        WebExporterOptionsBaseDescriptionMetadata.d(a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebExporterEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterEventDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Exporter", "ExportedType:WebBaseExporter");
        a.item("Options", "ExportedType:WebExporterOptionsBase");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
        a.item("Cancel", "Boolean");
    };
    WebExporterEventDetailDescriptionMetadata.d = function (a) {
        WebExporterEventDetailDescriptionMetadata.b(a);
        a.ac("WebExporterEventDetail", function () { return new WebExporterEventDetailDescription(); });
        a.ab("WebExporterEventDetail", WebExporterEventDetailDescriptionMetadata.a);
    };
    WebExporterEventDetailDescriptionMetadata.$t = markType(WebExporterEventDetailDescriptionMetadata, 'WebExporterEventDetailDescriptionMetadata');
    WebExporterEventDetailDescriptionMetadata.a = null;
    return WebExporterEventDetailDescriptionMetadata;
}(Base));
export { WebExporterEventDetailDescriptionMetadata };
